.. highlight:: shell

============
Installation
============

At the command line::

    $ easy_install with-venv

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv with-venv
    $ pip install with-venv
